'use strict'
const path = require('path')

function resolve(dir) {
	return path.join(__dirname, dir)
}

const name = process.env.VUE_APP_TITLE || '铁谷管理系统' // 网页标题

const port = process.env.port || process.env.npm_config_port || 80 // 端口

module.exports = {
	publicPath: process.env.NODE_ENV === 'production' ? '/' : '/',
	outputDir: 'dist',
	assetsDir: 'static',
	lintOnSave: process.env.NODE_ENV === 'development',
	productionSourceMap: false,
	devServer: {
		host: '0.0.0.0',
		port: port,
		open: true,
		proxy: {
			[process.env.VUE_APP_BASE_API]: {
				target: `http://192.168.0.104:9098`,
				changeOrigin: true,
				pathRewrite: {
					['^' + process.env.VUE_APP_BASE_API]: ''
				}
			}
		},
		disableHostCheck: true
	},
	configureWebpack: {
		name: name,
		resolve: {
			alias: {
				'@': resolve('src')
			}
		}
	},
	chainWebpack(config) {
		config.plugins.delete('preload')
		config.plugins.delete('prefetch')
		config.module.rule('svg').exclude.add(resolve('src/assets/icons')).end()
		config.module
			.rule('icons')
			.test(/\.svg$/)
			.include.add(resolve('src/assets/icons'))
			.end()
			.use('svg-sprite-loader')
			.loader('svg-sprite-loader')
			.options({
				symbolId: 'icon-[name]'
			})
			.end()

		config.when(process.env.NODE_ENV !== 'development', (config) => {
			config
				.plugin('ScriptExtHtmlWebpackPlugin')
				.after('html')
				.use('script-ext-html-webpack-plugin', [
					{
						inline: /runtime\..*\.js$/
					}
				])
				.end()
			config.optimization
				.minimize(true)
				.minimizer('terser')
				.tap((args) => {
					let { terserOptions } = args[0]
					terserOptions.compress.drop_console = true
					terserOptions.compress.drop_debugger = true
					return args
				})
			config.optimization.splitChunks({
				chunks: 'all',
				cacheGroups: {
					libs: {
						name: 'chunk-libs',
						test: /[\\/]node_modules[\\/]/,
						priority: 10,
						chunks: 'initial' // only package third parties that are initially dependent
					},
					elementUI: {
						name: 'chunk-elementUI', // split elementUI into a single package
						priority: 20, // the weight needs to be larger than libs and app or it will be packaged into libs or app
						test: /[\\/]node_modules[\\/]_?element-ui(.*)/ // in order to adapt to cnpm
					},
					commons: {
						name: 'chunk-commons',
						test: resolve('src/components'), // can customize your rules
						minChunks: 3, //  minimum common number
						priority: 5,
						reuseExistingChunk: true
					}
				}
			})
			config.optimization.runtimeChunk('single'),
				{
					from: path.resolve(__dirname, './public/robots.txt'), //防爬虫文件
					to: './' //到根目录下
				}
		})
	}
}
